/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corp.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsIScreen.idl"

[scriptable, uuid(e224bd44-252b-4b66-b869-99738250904a)]
interface nsIScreenManager : nsISupports
{
    //
    // Returns the screen that contains the rectangle. If the rect overlaps
    // multiple screens, it picks the screen with the greatest area of intersection.
    //
    // The coordinates are in pixels (not twips) and in screen coordinates.
    //
  nsIScreen screenForRect ( in long left, in long top, in long width, in long height ) ;
  
    // The screen with the menubar/taskbar. This shouldn't be needed very
    // often.
  readonly attribute nsIScreen primaryScreen;
  
    // Holds the number of screens that are available
  readonly attribute unsigned long numberOfScreens;

    // Returns the nsIScreen instance for the given native widget pointer;
    // the pointer is specific to the particular widget implementation,
    // and is generally of the same type that NS_NATIVE_WIDGET is.
  [noscript] nsIScreen screenForNativeWidget ( in voidPtr nativeWidget );
};


%{ C++

%}
